gopid

package module
v0.0.0-...-4067ab3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 5 Imported by: 0

README

ksql

GoDoc license

A simple go utility to write a service pid to /var/run on linux systems

Install

  go get github.com/kahoon/gopid

Usage

package main

import (
       "github.com/kahoon/gopid"
)

func main() {
     err := gopid.Run("svcname") // will write the service pid to /var/run/svcname.pid
}

Documentation

Overview

A simple go utility to run a service pid to /var/run on linux systems

Index

Constants

const (
	PATH = "/var/run"
	EXT  = "pid"
)

Variables

var (
	ErrNameEmpty = errors.New("gopid: empty service name")
)

Functions

func Run

func Run(svcname string) error

Types

This section is empty.

Jump to